@@ -14,14 +14,14 @@ use strict;
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Wed Jul 13 12:01:19 PDT 2005
+## Configuration time: Fri Feb  3 13:13:48 CST 2006
 ## Configured by     : root
-## Target system     : linux midas 2.4.31 #6 sun jun 5 19:04:47 pdt 2005 i686 unknown unknown gnulinux 
+## Target system     : linux tree 2.4.32 #6 fri jan 13 16:38:06 cst 2006 i686 athlon-4 i386 gnulinux 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
 
-our $summary : unique = <<'!END!';
+our $summary = <<'!END!';
 Summary of my $package (revision $revision $version_patchlevel_string) configuration:
   Platform:
     osname=$osname, osvers=$osvers, archname=$archname
@@ -78,11 +78,11 @@ PERL_API_SUBVERSION='0'
 PERL_API_VERSION='8'
 PERL_CONFIG_SH='true'
 PERL_REVISION='5'
-PERL_SUBVERSION='7'
+PERL_SUBVERSION='8'
 PERL_VERSION='8'
 RCSfile='$RCSfile'
 Revision='$Revision'
-SUBVERSION='7'
+SUBVERSION='8'
 Source=''
 State=''
 _a='.a'
@@ -98,8 +98,8 @@ api_subversion='0'
 api_version='8'
 api_versionstring='5.8.0'
 ar='ar'
-archlib='/usr/lib/perl5/5.8.7/i486-linux'
-archlibexp='/usr/lib/perl5/5.8.7/i486-linux'
+archlib='/usr/lib/perl5/5.8.8/i486-linux'
+archlibexp='/usr/lib/perl5/5.8.8/i486-linux'
 archname64=''
 archname='i486-linux'
 archobjs=''
@@ -118,14 +118,14 @@ cat='cat'
 cc='cc'
 cccdlflags='-fPIC'
 ccdlflags='-Wl,-E'
-ccflags='-fno-strict-aliasing -pipe -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
+ccflags='-fno-strict-aliasing -pipe -Wdeclaration-after-statement -I/usr/local/include -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
 ccflags_uselargefiles='-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
 ccname='gcc'
-ccsymbols='__GNUC_MINOR__=3 __GNUC_PATCHLEVEL__=6'
+ccsymbols=''
 ccversion=''
 cf_by='root'
-cf_email='root@midas.slackware.lan'
-cf_time='Wed Jul 13 12:01:19 PDT 2005'
+cf_email='root@tree.slackware.lan'
+cf_time='Fri Feb  3 13:13:48 CST 2006'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -138,23 +138,23 @@ config_arg1='-de'
 config_arg2='-Dprefix=/usr'
 config_arg3='-Dcccdlflags=-fPIC'
 config_arg4='-Dinstallprefix=/usr'
-config_arg5='-Doptimize=-O2 -march=i486 -mcpu=i686'
-config_arg6='-Dinc_version_list=5.8.6 5.8.5 5.8.4 5.8.3 5.8.2 5.8.1 5.8.0'
+config_arg5='-Doptimize=-O2 -march=i486 -mtune=i686'
+config_arg6='-Dinc_version_list=5.8.7 5.8.6 5.8.5 5.8.4 5.8.3 5.8.2 5.8.1 5.8.0'
 config_arg7='-Darchname=i486-linux'
 config_argc='7'
-config_args='-de -Dprefix=/usr -Dcccdlflags=-fPIC -Dinstallprefix=/usr -Doptimize=-O2 -march=i486 -mcpu=i686 -Dinc_version_list=5.8.6 5.8.5 5.8.4 5.8.3 5.8.2 5.8.1 5.8.0 -Darchname=i486-linux'
+config_args='-de -Dprefix=/usr -Dcccdlflags=-fPIC -Dinstallprefix=/usr -Doptimize=-O2 -march=i486 -mtune=i686 -Dinc_version_list=5.8.7 5.8.6 5.8.5 5.8.4 5.8.3 5.8.2 5.8.1 5.8.0 -Darchname=i486-linux'
 contains='grep'
 cp='cp'
 cpio=''
 cpp='cpp'
 cpp_stuff='42'
-cppccsymbols='__GNUC__=3'
-cppflags='-fno-strict-aliasing -pipe -I/usr/local/include'
+cppccsymbols=''
+cppflags='-fno-strict-aliasing -pipe -Wdeclaration-after-statement -I/usr/local/include'
 cpplast='-'
 cppminus='-'
 cpprun='cc -E'
 cppstdin='cc -E'
-cppsymbols='__ELF__=1 _FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=3 __GNUC_MINOR__=3 __GNU_LIBRARY__=6 _LARGEFILE_SOURCE=1 _POSIX_C_SOURCE=199506 _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_LARGEFILE=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 i386=1 __i386=1 __i386__=1 __i486=1 __i486__=1 linux=1 __linux=1 __linux__=1 unix=1 __unix=1 __unix__=1'
+cppsymbols='__ELF__=1 _FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=3 __GNUC__=3 __GNUC_MINOR__=4 __GNU_LIBRARY__=6 _LARGEFILE_SOURCE=1 _POSIX_C_SOURCE=199506L _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_LARGEFILE=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 i386=1 __i386=1 __i386__=1 __i486=1 __i486__=1 linux=1 __linux=1 __linux__=1 unix=1 __unix=1 __unix__=1'
 crypt_r_proto='0'
 cryptlib=''
 csh='csh'
@@ -183,7 +183,13 @@ d_archlib='define'
 d_asctime_r='undef'
 d_atolf='undef'
 d_atoll='define'
-d_attribut='define'
+d_attribute_format='define'
+d_attribute_malloc='define'
+d_attribute_nonnull='define'
+d_attribute_noreturn='define'
+d_attribute_pure='define'
+d_attribute_unused='define'
+d_attribute_warn_unused_result='define'
 d_bcmp='define'
 d_bcopy='define'
 d_bsd='undef'
@@ -197,6 +203,7 @@ d_chown='define'
 d_chroot='define'
 d_chsize='undef'
 d_class='undef'
+d_clearenv='define'
 d_closedir='define'
 d_cmsghdr_s='define'
 d_const='define'
@@ -265,6 +272,7 @@ d_fstatvfs='define'
 d_fsync='define'
 d_ftello='define'
 d_ftime='undef'
+d_futimes='define'
 d_getcwd='define'
 d_getespwnam='undef'
 d_getfsstat='undef'
@@ -348,6 +356,8 @@ d_longlong='define'
 d_lseekproto='define'
 d_lstat='define'
 d_madvise='define'
+d_malloc_good_size='undef'
+d_malloc_size='undef'
 d_mblen='define'
 d_mbstowcs='define'
 d_mbtowc='define'
@@ -384,6 +394,7 @@ d_mymalloc='undef'
 d_nice='define'
 d_nl_langinfo='define'
 d_nv_preserves_uv='define'
+d_nv_zero_is_allbits_zero='define'
 d_off64_t='undef'
 d_old_pthread_create_joinable='undef'
 d_oldpthreads='undef'
@@ -484,6 +495,7 @@ d_socket='define'
 d_socklen_t='define'
 d_sockpair='define'
 d_socks5_init='undef'
+d_sprintf_returns_strlen='define'
 d_sqrtl='define'
 d_srand48_r='undef'
 d_srandom_r='undef'
@@ -544,6 +556,7 @@ d_umask='define'
 d_uname='define'
 d_union_semun='undef'
 d_unordered='undef'
+d_unsetenv='define'
 d_usleep='define'
 d_usleepproto='define'
 d_ustat='define'
@@ -566,9 +579,9 @@ d_xenix='undef'
 date='date'
 db_hashtype='u_int32_t'
 db_prefixtype='size_t'
-db_version_major='3'
-db_version_minor='3'
-db_version_patch='11'
+db_version_major='4'
+db_version_minor='4'
+db_version_patch='20'
 defvoidused='15'
 direntrytype='struct dirent'
 dlext='so'
@@ -603,11 +616,11 @@ fpostype='fpos_t'
 freetype='void'
 from=':'
 full_ar='/usr/bin/ar'
-full_csh='/bin/csh'
+full_csh='/bin/tcsh'
 full_sed='/usr/bin/sed'
 gccansipedantic=''
 gccosandvers=''
-gccversion='3.3.6'
+gccversion='3.4.5'
 getgrent_r_proto='0'
 getgrgid_r_proto='0'
 getgrnam_r_proto='0'
@@ -635,7 +648,7 @@ gidtype='gid_t'
 glibpth='/usr/shlib  /lib /usr/lib /usr/lib/386 /lib/386 /usr/ccs/lib /usr/ucblib /usr/local/lib '
 gmake='gmake'
 gmtime_r_proto='0'
-gnulibc_version='2.3.5'
+gnulibc_version='2.3.6'
 grep='grep'
 groupcat='cat /etc/group'
 groupstype='gid_t'
@@ -739,11 +752,11 @@ i_varargs='undef'
 i_varhdr='stdarg.h'
 i_vfork='undef'
 ignore_versioned_solibs='y'
-inc_version_list='5.8.6 5.8.5 5.8.4 5.8.3 5.8.2 5.8.1 5.8.0'
-inc_version_list_init='"5.8.6","5.8.5","5.8.4","5.8.3","5.8.2","5.8.1","5.8.0",0'
+inc_version_list='5.8.7 5.8.6 5.8.5 5.8.4 5.8.3 5.8.2 5.8.1 5.8.0'
+inc_version_list_init='"5.8.7","5.8.6","5.8.5","5.8.4","5.8.3","5.8.2","5.8.1","5.8.0",0'
 incpath=''
 inews=''
-installarchlib='/usr/lib/perl5/5.8.7/i486-linux'
+installarchlib='/usr/lib/perl5/5.8.8/i486-linux'
 installbin='/usr/bin'
 installhtml1dir=''
 installhtml3dir=''
@@ -751,13 +764,13 @@ installman1dir='/usr/share/man/man1'
 installman3dir='/usr/share/man/man3'
 installprefix='/usr'
 installprefixexp='/usr'
-installprivlib='/usr/lib/perl5/5.8.7'
+installprivlib='/usr/lib/perl5/5.8.8'
 installscript='/usr/bin'
-installsitearch='/usr/lib/perl5/site_perl/5.8.7/i486-linux'
+installsitearch='/usr/lib/perl5/site_perl/5.8.8/i486-linux'
 installsitebin='/usr/bin'
 installsitehtml1dir=''
 installsitehtml3dir=''
-installsitelib='/usr/lib/perl5/site_perl/5.8.7'
+installsitelib='/usr/lib/perl5/site_perl/5.8.8'
 installsiteman1dir='/usr/share/man/man1'
 installsiteman3dir='/usr/share/man/man3'
 installsitescript='/usr/bin'
@@ -785,7 +798,7 @@ ldflags_uselargefiles=''
 ldlibpthname='LD_LIBRARY_PATH'
 less='less'
 lib_ext='.a'
-libc='/lib/libc-2.3.5.so'
+libc='/lib/libc-2.3.6.so'
 libperl='libperl.a'
 libpth='/usr/local/lib /lib /usr/lib'
 libs='-lnsl -lgdbm -ldb -ldl -lm -lcrypt -lutil -lc'
@@ -834,8 +847,8 @@ multiarch='undef'
 mv=''
 myarchname='i686-linux'
 mydomain='.slackware.lan'
-myhostname='midas'
-myuname='linux midas 2.4.31 #6 sun jun 5 19:04:47 pdt 2005 i686 unknown unknown gnulinux '
+myhostname='tree'
+myuname='linux tree 2.4.32 #6 fri jan 13 16:38:06 cst 2006 i686 athlon-4 i386 gnulinux '
 n='-n'
 need_va_copy='undef'
 netdb_hlen_type='size_t'
@@ -859,10 +872,10 @@ nvtype='double'
 o_nonblock='O_NONBLOCK'
 obj_ext='.o'
 old_pthread_create_joinable=''
-optimize='-O2 -march=i486 -mcpu=i686'
+optimize='-O2 -march=i486 -mtune=i686'
 orderlib='false'
 osname='linux'
-osvers='2.4.31'
+osvers='2.4.32'
 otherlibdirs=' '
 package='perl5'
 pager='/usr/bin/less'
@@ -872,7 +885,7 @@ path_sep=':'
 perl5=''
 perl=''
 perl_patchlevel=''
-perladmin='root@midas.slackware.lan'
+perladmin='root@tree.slackware.lan'
 perllibs='-lnsl -ldl -lm -lcrypt -lutil -lc'
 perlpath='/usr/bin/perl'
 pg='pg'
@@ -883,8 +896,8 @@ pmake=''
 pr=''
 prefix='/usr'
 prefixexp='/usr'
-privlib='/usr/lib/perl5/5.8.7'
-privlibexp='/usr/lib/perl5/5.8.7'
+privlib='/usr/lib/perl5/5.8.8'
+privlibexp='/usr/lib/perl5/5.8.8'
 procselfexe='"/proc/self/exe"'
 prototype='define'
 ptrsize='4'
@@ -945,17 +958,17 @@ sig_num='0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
 sig_num_init='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 6, 17, 29, 31, 0'
 sig_size='69'
 signal_t='void'
-sitearch='/usr/lib/perl5/site_perl/5.8.7/i486-linux'
-sitearchexp='/usr/lib/perl5/site_perl/5.8.7/i486-linux'
+sitearch='/usr/lib/perl5/site_perl/5.8.8/i486-linux'
+sitearchexp='/usr/lib/perl5/site_perl/5.8.8/i486-linux'
 sitebin='/usr/bin'
 sitebinexp='/usr/bin'
 sitehtml1dir=''
 sitehtml1direxp=''
 sitehtml3dir=''
 sitehtml3direxp=''
-sitelib='/usr/lib/perl5/site_perl/5.8.7'
+sitelib='/usr/lib/perl5/site_perl/5.8.8'
 sitelib_stem='/usr/lib/perl5/site_perl'
-sitelibexp='/usr/lib/perl5/site_perl/5.8.7'
+sitelibexp='/usr/lib/perl5/site_perl/5.8.8'
 siteman1dir='/usr/share/man/man1'
 siteman1direxp='/usr/share/man/man1'
 siteman3dir='/usr/share/man/man3'
@@ -992,7 +1005,7 @@ stdio_stream_array=''
 strerror_r_proto='0'
 strings='/usr/include/string.h'
 submit=''
-subversion='7'
+subversion='8'
 sysman='/usr/share/man/man1'
 tail=''
 tar=''
@@ -1076,8 +1089,8 @@ vendorprefix=''
 vendorprefixexp=''
 vendorscript=''
 vendorscriptexp=''
-version='5.8.7'
-version_patchlevel_string='version 8 subversion 7'
+version='5.8.8'
+version_patchlevel_string='version 8 subversion 8'
 versiononly='undef'
 vi=''
 voidflags='15'
@@ -1096,8 +1109,8 @@ s/(byteorder=)(['"]).*?\2/$1$2$Config::byteorder$2/m;
 
 my $config_sh_len = length $_;
 
-our $Config_SH_expanded : unique = "\n$_" . << 'EOVIRTUAL';
-ccflags_nolargefiles='-fno-strict-aliasing -pipe -I/usr/local/include '
+our $Config_SH_expanded = "\n$_" . << 'EOVIRTUAL';
+ccflags_nolargefiles='-fno-strict-aliasing -pipe -Wdeclaration-after-statement -I/usr/local/include '
 ldflags_nolargefiles=' -L/usr/local/lib'
 libs_nolargefiles='-lnsl -lgdbm -ldb -ldl -lm -lcrypt -lutil -lc'
 libswanted_nolargefiles='sfio socket inet nsl nm ndbm gdbm dbm db malloc dl dld ld sun m crypt sec util c cposix posix ucb BSD'
